@@ -1,14 +1,12 @@
-from .wordtile import *
-from .console import *
-from .mocio import *
-from .border import *
-from .ui import *
 import threading
 import pygame
-
-window = Console()
+from .wordtile import *
+from .console import *
+this_console = Console()
+from .mocio import *
 moprint = Printer()
 moinput = Reader()
+from .ui import *
 
 
 def init(width, height, font_height, title) -> None:
@@ -23,19 +21,19 @@ def init(width, height, font_height, title) -> None:
     ok = False
 
     def create_console():
-        global window
-        window.init(width, height, font_height, title)
+        global this_console
+        this_console.init(width, height, font_height, title)
         nonlocal ok
         ok = True
-        window.start()
+        this_console.start()
 
     thread = threading.Thread(target=create_console)
     thread.start()
     while not ok:
         pygame.time.wait(10)
-    global window
-    moprint.bind(window)
-    moinput.bind(window, moprint)
+    global this_console
+    moprint.bind(this_console)
+    moinput.bind(this_console, moprint)
 
 
 def close() -> None:
