@@ -4,6 +4,7 @@ import pygame
 from typing import Tuple, List
 import queue
 import os
+import random
 
 
 class Console:
@@ -37,12 +38,12 @@ class Console:
     fps_last_update_time: int
     fps_cnt: int
     buffer_surface: pygame.Surface
-
+    h_lines: List[Tuple[int, int, int]]
+    v_lines: List[Tuple[int, int, int]]
     def __init__(self):
         """
         初始化，别问我为什么不在这里定义成员变量，因为 pygame 的所有绘制相关函数必须在一个线程里执行，包括 init。
         """
-        pass
 
     def init(self, width, height, font_height, title) -> None:
         """
@@ -57,6 +58,7 @@ class Console:
         self.height = height
         self.height_offset = 0
         pygame.init()
+
         self.font_path = os.path.dirname(os.path.abspath(__file__)) + r'/Apple Hei.ttf'
         if not os.path.exists(os.path.dirname(os.path.abspath(__file__))):
             os.makedirs(os.path.dirname(os.path.abspath(__file__)))
@@ -64,11 +66,13 @@ class Console:
             from .Apple_Hei_packed import unpack
             unpack(self.font_path)
         self.font = pygame.font.Font(self.font_path, font_height)
-        [self.text_width, self.text_height] = self.font.size('a')[0],self.font.size('j')[1]
+
+        #self.font=pygame.font.SysFont('notosansmonocjksc',font_height)
+        [self.text_width, self.text_height] = self.font.size('a')[0], self.font.size('j')[1]
         self.text_height -= self.height_offset * 2
         [self.window_width, self.window_height] = [self.width * self.text_width,
                                                    self.height * self.text_height]
-        self.data = [[WordTile(' ', pygame.Color('#39C5BB'), pygame.Color('white')) for i in range(width)] for j in
+        self.data = [[WordTile(' ', pygame.Color('white'), pygame.Color('black')) for i in range(width)] for j in
                      range(height)]
         self.data_updated = True
         self.window = pygame.display.set_mode((self.window_width, self.window_height), flags=pygame.DOUBLEBUF)
@@ -87,6 +91,8 @@ class Console:
         self.fps = 60
         self.fps_last_update_time = pygame.time.get_ticks()
         self.fps_cnt = 0
+        self.v_lines = []
+        self.h_lines = []
 
     def __render_single_char(self, i, j) -> None:
         """
@@ -102,15 +108,29 @@ class Console:
             text_width *= 2
         pygame.draw.rect(self.window, obj.back_color, (x, y, text_width, text_height))
         text = self.font.render(obj.char, True, obj.fore_color, obj.back_color)
-        self.window.blit(text.subsurface(pygame.Rect(0, self.height_offset, min(text_width, text.get_width()),
-                                                     min(text_height,text.get_height()) - self.height_offset * 2)), (x, y))
+        text=text.subsurface(pygame.Rect(0, self.height_offset,text.get_width(),
+                                                     min(text_height, text.get_height()) - self.height_offset * 2))
+        if text.get_width()>text_width:
+            text=pygame.transform.scale(text,(text_width,text_height))
+        # text = self.font.render(obj.char, True, obj.fore_color, random.choice(['red','white','yellow','green']))
+        self.window.blit(text,(x+(text_width-text.get_width())/2, y))
+        #self.window.blit(text, (x, y))
 
     def __render_cursor(self) -> None:
-        pygame.draw.line(self.window, pygame.color.Color('black') if self.cursor_visible else self.cursor_bkcolor,
+        pygame.draw.line(self.window, pygame.color.Color('white') if self.cursor_visible else self.cursor_bkcolor,
                          (self.cursor_y * self.text_width, self.cursor_x * self.text_height),
                          (self.cursor_y * self.text_width,
                           self.cursor_x * self.text_height + self.text_height - 1), self.cursor_width)
 
+    def __render_border(self) -> None:
+        border_color='#F0F0F0'
+        x_offset=-1
+        y_offset=-1
+        for x, y1, y2 in self.v_lines:
+            pygame.draw.line(self.window, border_color, (x+x_offset, y1), (x+x_offset, y2), 1)
+        for y, x1, x2 in self.h_lines:
+            pygame.draw.line(self.window, border_color, (x1, y+y_offset), (x2, y+y_offset), 1)
+
     def __render(self) -> None:
         """
         渲染
@@ -134,6 +154,7 @@ class Console:
                         self.__render_single_char(i, j)
         if self.enabled_cursor_twinkling:
             self.__render_cursor()
+        self.__render_border()
         pygame.display.flip()
 
     def start(self) -> None:
@@ -209,3 +230,31 @@ class Console:
         """
         self.enabled_cursor_twinkling = False
         self.__render_single_char(self.cursor_x, self.cursor_y)
+
+    def __draw_vertical_border(self, x, y1, y2) -> None:
+        """
+        画竖边框
+
+        :param x: 边框的 x 坐标
+        :param y1: 边框一端的 y 坐标
+        :param y2: 边框另一端的 y 坐标
+        """
+        if y1 > y2:
+            [y1, y2] = [y2, y1]
+        self.v_lines.append((x * self.text_width, y1 * self.text_height, y2 * self.text_height))
+
+    def __draw_horizontal_border(self, y, x1, x2) -> None:
+        """
+        画横边框
+
+        :param y: 边框的 y 坐标
+        :param x1: 边框一端的 x 坐标
+        :param x2: 边框另一端的 x 坐标
+        """
+        if x1 > x2:
+            [x1, x2] = [x2, x1]
+        self.h_lines.append((y * self.text_height, x1 * self.text_width, x2 * self.text_width))
+
+    def __clear_borders(self) -> None:
+        self.v_lines.clear()
+        self.h_lines.clear()
