@@ -63,8 +63,8 @@ class Printer:
         self.x = 0
         self.y = 0
         self.console = target
-        self.fore_color = pygame.Color('#39C5BB')
-        self.back_color = pygame.Color('white')
+        self.fore_color = pygame.Color('white')
+        self.back_color = pygame.Color('black')
         self.rect = (0, 0, self.console.width - 1, self.console.height - 1)
         self.enabled_auto_flush = True
 
