@@ -1,7 +1,5 @@
 import pygame
 import moceris.console
-
-
 def to_absolute_rect(rect):
     return [rect.x, rect.y, rect.x + rect.width - 1, rect.y + rect.height - 1]
 
@@ -38,13 +36,13 @@ class Element:
         """
         pass
 
-    def register(self, r_border, r_dict, rect, parent, scene) -> None:
+    def register(self,console, r_dict, rect, parent, scene) -> None:
         """
         向 Scene 注册本控件，不需要手动调用此函数
 
         欲重写该函数请参照基类格式
 
-        :param r_border: Scene 或上层 Element 传递的 Border 引用
+        :param console: Console 类的指针
         :param r_dict:  Scene 或上层 Element 传递的 class_name 字典引用
         :param rect: Scene 或上层 Element 传递的 rect，表示该元素将被限制在此 rect 内绘制（可以直接改 Console.rect 突破）
         :param parent: 父控件指针
@@ -129,13 +127,13 @@ class VerticalPanel(Element):
         self.have_border = have_border
         self.n_height = n_height
 
-    def register(self, r_border, r_dict, rect: pygame.Rect, parent, scene):
-        super().register(r_border, r_dict, rect, parent, scene)
+    def register(self, console, r_dict, rect: pygame.Rect, parent, scene):
+        super().register(console,r_dict, rect, parent, scene)
         if self.have_border:
-            r_border.draw_horizontal(self.rect.y + self.n_height, self.rect.x - 1, self.rect.x + self.rect.width + 1)
-        self.n_child.register(r_border, r_dict, pygame.Rect(rect.x, rect.y, rect.width, self.n_height), self, scene)
-        self.s_child.register(r_border, r_dict, pygame.Rect(rect.x, rect.y + self.n_height + 1, rect.width,
-                                                            rect.height - self.n_height - 1), self, scene)
+            console._Console__draw_horizontal_border(self.rect.y + self.n_height, self.rect.x, self.rect.x + self.rect.width)
+        self.n_child.register(console, r_dict, pygame.Rect(rect.x, rect.y, rect.width, self.n_height), self, scene)
+        self.s_child.register(console, r_dict, pygame.Rect(rect.x, rect.y + self.n_height, rect.width,
+                                                            rect.height - self.n_height), self, scene)
 
     def display(self, *args):
         if not self.child_updated:
@@ -170,13 +168,13 @@ class HorizontalPanel(Element):
         self.have_border = have_border
         self.w_width = w_width
 
-    def register(self, r_border, r_dict: dict, rect, parent, scene):
-        super().register(r_border, r_dict, rect, parent, scene)
+    def register(self, console, r_dict: dict, rect, parent, scene):
+        super().register(console,r_dict, rect, parent, scene)
         if self.have_border:
-            r_border.draw_vertical(self.rect.x + self.w_width, self.rect.y - 1, self.rect.y + self.rect.height + 1)
-        self.w_child.register(r_border, r_dict, pygame.Rect(rect.x, rect.y, self.w_width, rect.height), self, scene)
-        self.e_child.register(r_border, r_dict,
-                              pygame.Rect(rect.x + self.w_width + 1, rect.y, rect.width - self.w_width - 1,
+            console._Console__draw_vertical_border(self.rect.x + self.w_width, self.rect.y, self.rect.y + self.rect.height)
+        self.w_child.register(console, r_dict, pygame.Rect(rect.x, rect.y, self.w_width, rect.height), self, scene)
+        self.e_child.register(console, r_dict,
+                              pygame.Rect(rect.x + self.w_width, rect.y, rect.width - self.w_width,
                                           rect.height), self, scene)
 
     def display(self, *args):
@@ -199,14 +197,13 @@ class Scene:
     """
 
     def __init__(self, layout):
-        from moceris.console import window
-        self.width = window.width
-        self.height = window.height
+        from moceris.console import this_console
+        self.width = this_console.width
+        self.height = this_console.height
         self.layout = layout
         self.element_dict = {}
-        from .border import Border
-        self.border = Border(self.width, self.height)
-        self.layout.register(self.border, self.element_dict, pygame.Rect(0, 0, self.width, self.height), None, self)
+        this_console._Console__clear_borders()
+        self.layout.register(this_console,self.element_dict, pygame.Rect(0, 0, self.width, self.height), None, self)
 
     def display(self, *args) -> None:
         """
@@ -220,7 +217,6 @@ class Scene:
         if self.layout is not None:
             self.layout.display(args)
         moprint.default_rect()
-        self.border.display()
 
     def update(self, class_name, *args) -> None:
         """
